@@ -1,27 +1,27 @@
 BUILD_BIT = '64bit'
 BUILD_CPU = 'ARMv8 (64-bit) Family 8 Model D49 Revision   0, MICROSOFT CORPORATION'
-BUILD_DATE = '2025-07-06'
+BUILD_DATE = '2025-08-25'
 BUILD_MACHINE = 'ARM64'
 BUILD_OS = 'Microsoft Windows 11 Enterprise'
-BUILD_TIME = '14:20'
+BUILD_TIME = '06:21'
 BUILD_TYPE = ''
-COMPILER_VERSION = 'clang version 20.1.7'
+COMPILER_VERSION = 'clang version 20.1.8'
 CYTHON_VERSION = '3.1.2'
-LINKER_VERSION = 'LLD 20.1.7 (https://github.com/msys2/MINGW-packages 50e6b387b9c5758905c2aa3f4526ae8647198323) (compatible with GNU linkers)'
+LINKER_VERSION = 'LLD 20.1.8 (https://github.com/msys2/MINGW-packages 2c07222d2d8701ee258b1f85645b32661c2869f3) (compatible with GNU linkers)'
 NVCC_VERSION = ''
 PYTHON_VERSION = '3.12.11'
 lib_base = '2022.06-1'
 lib_basedevel = '2024.11-1'
 lib_bash = '5.2.037-2'
 lib_bashcompletion = '2.16.0-1'
-lib_binutils = '2.44-2'
+lib_binutils = '2.45-1'
 lib_bison = '3.8.2-5'
 lib_brotli = '1.1.0-2'
 lib_bsdtar = '3.8.1-1'
 lib_bzip2 = '1.0.8-4'
-lib_cacertificates = '20241223-1'
+lib_cacertificates = '20250419-1'
 lib_coreutils = '8.32-5'
-lib_curl = '8.14.1-2'
+lib_curl = '8.15.0-1'
 lib_dash = '0.5.12-1'
 lib_db = '6.2.32-5'
 lib_diffstat = '1.68-1'
@@ -32,31 +32,31 @@ lib_filesystem = '2025.05.08-2'
 lib_findutils = '4.10.0-2'
 lib_flex = '2.6.4-4'
 lib_gawk = '5.3.2-1'
-lib_gcclibs = '15.1.0-2'
-lib_gdbm = '1.25-1'
+lib_gcclibs = '15.2.0-1'
+lib_gdbm = '1.26-1'
 lib_getent = '2.18.90-5'
 lib_gettext = '0.22.5-1'
-lib_gmp = '6.3.0-1'
+lib_gmp = '6.3.0-2'
 lib_gnupg = '2.4.8-1'
 lib_grep = '1~3.0-7'
 lib_gzip = '1.14-1'
 lib_heimdallibs = '7.8.0-5'
 lib_inetutils = '2.6-1'
-lib_info = '7.2-1'
+lib_info = '7.2-2'
 lib_less = '679-1'
 lib_libargp = '20241207-1'
 lib_libasprintf = '0.22.5-1'
 lib_libassuan = '3.0.2-1'
 lib_libbz2 = '1.0.8-4'
-lib_libcurl = '8.14.1-2'
+lib_libcurl = '8.15.0-1'
 lib_libdb = '6.2.32-5'
 lib_libedit = '20240808_3.1-1'
 lib_libexpat = '2.7.1-1'
 lib_libffi = '3.5.1-1'
-lib_libgcrypt = '1.11.1-1'
-lib_libgdbm = '1.25-1'
+lib_libgcrypt = '1.11.2-1'
+lib_libgdbm = '1.26-1'
 lib_libgettextpo = '0.22.5-1'
-lib_libgnutls = '3.8.9-1'
+lib_libgnutls = '3.8.10-1'
 lib_libgpgerror = '1.55-1'
 lib_libhogweed = '3.10.2-1'
 lib_libiconv = '1.18-1'
@@ -67,16 +67,16 @@ lib_liblz4 = '1.10.0-1'
 lib_liblzma = '5.8.1-1'
 lib_libnettle = '3.10.2-1'
 lib_libnghttp2 = '1.66.0-1'
-lib_libnghttp3 = '1.10.1-1'
-lib_libngtcp2 = '1.13.0-2'
+lib_libnghttp3 = '1.11.0-1'
+lib_libngtcp2 = '1.14.0-1'
 lib_libnpth = '1.8-1'
-lib_libopenssl = '3.5.1-1'
+lib_libopenssl = '3.5.2-1'
 lib_libp11kit = '0.25.5-2'
 lib_libpcre = '8.45-5'
 lib_libpcre28 = '10.45-1'
 lib_libpsl = '0.21.5-2'
-lib_libreadline = '8.2.013-1'
-lib_libsqlite = '3.50.2-1'
+lib_libreadline = '8.3.001-1'
+lib_libsqlite = '3.50.4-1'
 lib_libssh2 = '1.11.1-1'
 lib_libtasn1 = '4.20.0-1'
 lib_libunistring = '1.3-1'
@@ -87,15 +87,15 @@ lib_m4 = '1.4.19-2'
 lib_make = '4.4.1-2'
 lib_mingww64clangaarch64adwaitaicontheme = '48.1-1'
 lib_mingww64clangaarch64adwaitaiconthemelegacy = '46.2-1'
-lib_mingww64clangaarch64aom = '3.12.1-2'
-lib_mingww64clangaarch64atk = '2.56.3-1'
+lib_mingww64clangaarch64aom = '3.12.1-3'
+lib_mingww64clangaarch64atk = '2.56.4-1'
 lib_mingww64clangaarch64brotli = '1.1.0-5'
 lib_mingww64clangaarch64bzip2 = '1.0.8-3'
-lib_mingww64clangaarch64cairo = '1.18.4-2'
-lib_mingww64clangaarch64clang = '20.1.7-1'
-lib_mingww64clangaarch64clanglibs = '20.1.7-1'
-lib_mingww64clangaarch64compilerrt = '20.1.7-1'
-lib_mingww64clangaarch64crtgit = '13.0.0.r57.gc1a7f831b-1'
+lib_mingww64clangaarch64cairo = '1.18.4-3'
+lib_mingww64clangaarch64clang = '20.1.8-2'
+lib_mingww64clangaarch64clanglibs = '20.1.8-2'
+lib_mingww64clangaarch64compilerrt = '20.1.8-2'
+lib_mingww64clangaarch64crtgit = '13.0.0.r124.g2717de84e-1'
 lib_mingww64clangaarch64cython = '3.1.2-1'
 lib_mingww64clangaarch64dav1d = '1.5.1-1'
 lib_mingww64clangaarch64eglheaders = '1.5.r284.3ae2b7c-1'
@@ -104,108 +104,108 @@ lib_mingww64clangaarch64fontconfig = '2.17.1-1'
 lib_mingww64clangaarch64freetype = '2.13.3-1'
 lib_mingww64clangaarch64fribidi = '1.0.16-1'
 lib_mingww64clangaarch64gdkpixbuf2 = '2.42.12-4'
-lib_mingww64clangaarch64gettextruntime = '0.25.1-1'
+lib_mingww64clangaarch64gettextruntime = '0.26-1'
 lib_mingww64clangaarch64giflib = '5.2.2-1'
 lib_mingww64clangaarch64glesheaders = '3.2.r1065.7fc154c-1'
-lib_mingww64clangaarch64glib2 = '2.84.3-2'
+lib_mingww64clangaarch64glib2 = '2.84.4-1'
 lib_mingww64clangaarch64gobjectintrospectionruntime = '1.84.0-2'
 lib_mingww64clangaarch64graphite2 = '1.3.14-3'
-lib_mingww64clangaarch64gtk3 = '3.24.49-1'
-lib_mingww64clangaarch64gtkupdateiconcache = '3.24.49-1'
-lib_mingww64clangaarch64harfbuzz = '11.2.1-1'
-lib_mingww64clangaarch64headersgit = '13.0.0.r57.gc1a7f831b-1'
+lib_mingww64clangaarch64gtk3 = '3.24.50-1'
+lib_mingww64clangaarch64gtkupdateiconcache = '3.24.50-1'
+lib_mingww64clangaarch64harfbuzz = '11.4.3-1'
+lib_mingww64clangaarch64headersgit = '13.0.0.r124.g2717de84e-1'
 lib_mingww64clangaarch64hicoloricontheme = '0.18-1'
 lib_mingww64clangaarch64jbigkit = '2.1-5'
 lib_mingww64clangaarch64jsonglib = '1.10.6-1'
 lib_mingww64clangaarch64lcms2 = '2.17-1'
 lib_mingww64clangaarch64lerc = '4.0.0-1'
-lib_mingww64clangaarch64libavif = '1.3.0-1'
-lib_mingww64clangaarch64libc = '20.1.7-1'
+lib_mingww64clangaarch64libavif = '1.3.0-3'
+lib_mingww64clangaarch64libc = '20.1.8-1'
 lib_mingww64clangaarch64libdatrie = '0.2.13-3'
 lib_mingww64clangaarch64libdeflate = '1.24-1'
 lib_mingww64clangaarch64libepoxy = '1.5.10-7'
 lib_mingww64clangaarch64libffi = '3.5.1-1'
 lib_mingww64clangaarch64libiconv = '1.18-1'
-lib_mingww64clangaarch64libimagequant = '4.3.4-3'
+lib_mingww64clangaarch64libimagequant = '4.4.0-1'
 lib_mingww64clangaarch64libjpegturbo = '3.1.1-1'
 lib_mingww64clangaarch64libpng = '1.6.50-1'
-lib_mingww64clangaarch64libraqm = '0.10.2-1'
-lib_mingww64clangaarch64librsvg = '2.60.0-1'
+lib_mingww64clangaarch64libraqm = '0.10.3-1'
+lib_mingww64clangaarch64librsvg = '2.61.0-1'
 lib_mingww64clangaarch64libspng = '0.7.4-1'
 lib_mingww64clangaarch64libsystre = '1.0.2-1'
 lib_mingww64clangaarch64libthai = '0.1.29-3'
 lib_mingww64clangaarch64libtiff = '4.7.0-1'
 lib_mingww64clangaarch64libtre = '0.9.0-1'
-lib_mingww64clangaarch64libunwind = '20.1.7-1'
-lib_mingww64clangaarch64libvpx = '1.15.1-3'
-lib_mingww64clangaarch64libwebp = '1.5.0-1'
-lib_mingww64clangaarch64libwinpthread = '13.0.0.r57.gc1a7f831b-1'
-lib_mingww64clangaarch64libx264 = '0.164.r3161.a354f11-3'
-lib_mingww64clangaarch64libxml2 = '2.13.8-1'
+lib_mingww64clangaarch64libunwind = '20.1.8-1'
+lib_mingww64clangaarch64libvpx = '1.15.1-4'
+lib_mingww64clangaarch64libwebp = '1.6.0-1'
+lib_mingww64clangaarch64libwinpthread = '13.0.0.r124.g2717de84e-1'
+lib_mingww64clangaarch64libx264 = '0.165.r3222.b35605a-1'
+lib_mingww64clangaarch64libxml2 = '2.14.5-2'
 lib_mingww64clangaarch64libyuv = '1909.r2832.4db2af62d-1'
-lib_mingww64clangaarch64lld = '20.1.7-1'
-lib_mingww64clangaarch64llvmlibs = '20.1.7-1'
-lib_mingww64clangaarch64llvmtools = '20.1.7-1'
+lib_mingww64clangaarch64lld = '20.1.8-2'
+lib_mingww64clangaarch64llvmlibs = '20.1.8-2'
+lib_mingww64clangaarch64llvmtools = '20.1.8-2'
 lib_mingww64clangaarch64lz4 = '1.10.0-1'
 lib_mingww64clangaarch64lzo2 = '2.10-2'
 lib_mingww64clangaarch64mpdecimal = '4.0.1-1'
 lib_mingww64clangaarch64ncurses = '6.5.20241228-3'
 lib_mingww64clangaarch64openjpeg2 = '2.5.3-1'
-lib_mingww64clangaarch64openssl = '3.5.1-1'
-lib_mingww64clangaarch64pango = '1.56.4-1'
+lib_mingww64clangaarch64openssl = '3.5.2-1'
+lib_mingww64clangaarch64pango = '1.56.4-2'
 lib_mingww64clangaarch64pcre2 = '10.45-1'
-lib_mingww64clangaarch64pixman = '0.46.2-1'
+lib_mingww64clangaarch64pixman = '0.46.4-1'
 lib_mingww64clangaarch64pkgconf = '1~2.5.1-1'
 lib_mingww64clangaarch64python = '3.12.11-1'
-lib_mingww64clangaarch64pythonbuild = '1.2.2.post1-1'
+lib_mingww64clangaarch64pythonbuild = '1.3.0-1'
 lib_mingww64clangaarch64pythoncairo = '1.28.0-1'
 lib_mingww64clangaarch64pythoncomtypes = '1.4.11-1'
 lib_mingww64clangaarch64pythongobject = '3.52.3-1'
 lib_mingww64clangaarch64pythoninstaller = '0.7.0-4'
 lib_mingww64clangaarch64pythonpackaging = '25.0-1'
 lib_mingww64clangaarch64pythonpillow = '11.3.0-1'
-lib_mingww64clangaarch64pythonpyopengl = '3.1.9-2'
+lib_mingww64clangaarch64pythonpyopengl = '3.1.10-1'
 lib_mingww64clangaarch64pythonpyprojecthooks = '1.2.0-1'
 lib_mingww64clangaarch64pythonpyvda = '0.5.0-1'
 lib_mingww64clangaarch64pythonpywin32 = '310-1'
 lib_mingww64clangaarch64pythonsetproctitle = '1.3.6-1'
-lib_mingww64clangaarch64pythonsetuptools = '80.9.0-1'
+lib_mingww64clangaarch64pythonsetuptools = '80.9.0-2'
 lib_mingww64clangaarch64rav1e = '0.8.1-1'
-lib_mingww64clangaarch64readline = '8.2.013-1'
-lib_mingww64clangaarch64sharedmimeinfo = '2.4-1'
-lib_mingww64clangaarch64sqlite3 = '3.50.2-1'
-lib_mingww64clangaarch64svtav1 = '3.0.2-2'
+lib_mingww64clangaarch64readline = '8.3.001-1'
+lib_mingww64clangaarch64sharedmimeinfo = '2.4-3'
+lib_mingww64clangaarch64sqlite3 = '3.50.4-1'
+lib_mingww64clangaarch64svtav1 = '3.1.0-1'
 lib_mingww64clangaarch64tcl = '8.6.16-1'
 lib_mingww64clangaarch64termcap = '1.3.1-7'
 lib_mingww64clangaarch64tk = '8.6.16-1'
 lib_mingww64clangaarch64tzdata = '2025b-2'
 lib_mingww64clangaarch64wineditline = '2.208-1'
-lib_mingww64clangaarch64winpthreads = '13.0.0.r57.gc1a7f831b-1'
+lib_mingww64clangaarch64winpthreads = '13.0.0.r124.g2717de84e-1'
 lib_mingww64clangaarch64xxhash = '0.8.3-1'
 lib_mingww64clangaarch64xz = '5.8.1-2'
 lib_mingww64clangaarch64zlib = '1.3.1-1'
 lib_mingww64clangaarch64zstd = '1.5.7-1'
-lib_mintty = '1~3.7.8-1'
+lib_mintty = '1~3.8.0-1'
 lib_mpfr = '4.2.2-1'
 lib_msys2keyring = '1~20250619-1'
 lib_msys2launcher = '1.5-3'
-lib_msys2runtime = '3.6.3-5'
-lib_nano = '8.5-1'
+lib_msys2runtime = '3.6.4-1'
+lib_nano = '8.6-1'
 lib_ncurses = '6.5.20240831-2'
 lib_nettle = '3.10.2-1'
-lib_openssl = '3.5.1-1'
+lib_openssl = '3.5.2-1'
 lib_p11kit = '0.25.5-2'
-lib_pacman = '6.1.0-16'
+lib_pacman = '6.1.0-18'
 lib_pacmancontrib = '1.10.6-1'
 lib_pacmanmirrors = '20250607-1'
 lib_patch = '2.7.6-3'
-lib_perl = '5.38.4-2'
-lib_pinentry = '1.3.1-2'
+lib_perl = '5.40.3-1'
+lib_pinentry = '1.3.2-1'
 lib_rebase = '4.5.0-5'
 lib_sed = '4.9-1'
 lib_tar = '1.35-2'
-lib_texinfo = '7.2-1'
-lib_texinfotex = '7.2-1'
+lib_texinfo = '7.2-2'
+lib_texinfotex = '7.2-2'
 lib_time = '1.9-3'
 lib_tzcode = '2025b-1'
 lib_utillinux = '2.40.2-2'
